@@ -2,7 +2,7 @@
 #' @rdname FeatSelControl
 makeFeatSelControlSequential = function(same.resampling.instance = TRUE, impute.val = NULL, method,
   alpha = 0.01, beta = -0.001, maxit = NA_integer_, max.features = NA_integer_,
-  tune.threshold = FALSE, tune.threshold.args = list(), log.fun = NULL) {
+  tune.threshold = FALSE, tune.threshold.args = list(), log.fun = "default") {
 
   makeFeatSelControl(
     same.resampling.instance = same.resampling.instance,
