@@ -20,7 +20,7 @@ getFailureModelMsg.HomogeneousEnsembleModel = function(model) {
   mods = getLearnerModel(model, more.unwrap = FALSE)
   msgs = vcapply(mods, getFailureModelMsg)
   j = which.first(!is.na(msgs))
-  ifelse(j == 0L, NA_character_ , msgs[j])
+  ifelse(j == 0L, NA_character_, msgs[j])
 }
 
 #' @export
@@ -29,9 +29,9 @@ getFailureModelDump.HomogeneousEnsembleModel = function(model) {
   msgs = lapply(mods, getFailureModelDump)
   j = which.first(!is.null(msgs))
   ifelse(j == 0L, NULL, msgs[[j]])
-} 
+}
 
-#' Deprecated, use \code{getLearnerModel} instead.
+#' Deprecated, use `getLearnerModel` instead.
 #' @param model Deprecated.
 #' @param learner.models Deprecated.
 #' @export
@@ -54,11 +54,11 @@ getLearnerModel.HomogeneousEnsembleModel = function(model, more.unwrap = FALSE)
 # internal mini helper: return a matrix of predictions, either numeric for regr or character for classif
 # rows = newdata points, cols = ensembles members
 # does only work for responses, not probs, se, etc
-predictHomogeneousEnsemble = function(.learner, .model, .newdata, ...) {
+predictHomogeneousEnsemble = function(.learner, .model, .newdata, .subset = NULL, ...) {
   models = getLearnerModel(.model, more.unwrap = FALSE)
   # for classif we convert factor to char, nicer to handle later on
   preds = lapply(models, function(mod) {
-    p = predict(mod, newdata = .newdata, ...)$data$response
+    p = predict(mod, newdata = .newdata, subset = .subset, ...)$data$response
     if (is.factor(p))
       p = as.character(p)
     return(p)
