@@ -62,7 +62,7 @@
 # Unifrom: -value ... value, Normal: stddev
 
 # loss
-# Loss function: Automatic, CrossEntropy (for classification only), MeanSquare, Absolute (experimental) or Huber (experimental)
+# Loss function: Automatic, CrossEntropy (for classification only), Quadratic, Absolute (experimental) or Huber (experimental)
 
 # score_interval
 # Shortest time interval (in secs) between model scoring
@@ -188,7 +188,7 @@ makeRLearner.classif.h2o.deeplearning = function() {
         values = c("UniformAdaptive", "Uniform", "Normal"), default = "UniformAdaptive"),
       makeNumericLearnerParam("initial_weight_scale", default = 1),
       makeDiscreteLearnerParam("loss", values = c("Automatic", "CrossEntropy",
-        "MeanSquare", "Absolute", "Huber")),
+        "Quadratic", "Absolute", "Huber")),
       makeNumericLearnerParam("score_interval", default = 5),
       makeIntegerLearnerParam("score_training_samples", default = 10000),
       makeIntegerLearnerParam("score_validation_samples", default = 0),
@@ -219,9 +219,11 @@ makeRLearner.classif.h2o.deeplearning = function() {
       makeLogicalLearnerParam("reproducible", default = FALSE, tunable = FALSE),
       makeLogicalLearnerParam("export_weights_and_biases", default = FALSE, tunable = FALSE)
     ),
-    properties = c("twoclass", "multiclass", "numerics", "factors", "prob", "weights"),
+    properties = c("twoclass", "multiclass", "numerics", "factors", "prob", "weights", "missings"),
     name = "h2o.deeplearning",
-    short.name = "h2o.dl"
+    short.name = "h2o.dl",
+    note = 'The default value of `missing_values_handling` is `"MeanImputation"`, so missing values are automatically mean-imputed.',
+    callees = "h2o.deeplearning"
   )
 }
 
@@ -253,11 +255,9 @@ predictLearner.classif.h2o.deeplearning = function(.learner, .model, .newdata, .
 
   # check if class names are integers. if yes, colnames of p.df need to be adapted
   int = stri_detect_regex(p.df$predict, "^[[:digit:]]+$")
-  if (any(int)) {
-    pcol = stri_detect_regex("^p[[:digit:]]+$", colnames(p.df))
-    if (any(pcol))
-      colnames(p.df)[pcol] = stri_sub(colnames(p.df)[pcol], 2L)
-  }
+  pcol = stri_detect_regex(colnames(p.df), "^p[[:digit:]]+$")
+  if (any(int) && any(pcol))
+    colnames(p.df)[pcol] = stri_sub(colnames(p.df)[pcol], 2L)
 
   if (.learner$predict.type == "response") {
     return(p.df$predict)
