@@ -2,31 +2,31 @@
 #'
 #' @description
 #' Calculates numerical filter values for features.
-#' For a list of features, use \code{\link{listFilterMethods}}.
+#' For a list of features, use [listFilterMethods].
 #'
 #' @template arg_task
-#' @param method [\code{character}]\cr
+#' @param method ([character])\cr
 #'   Filter method(s), see above.
 #'   Default is \dQuote{randomForestSRC.rfsrc}.
-#' @param nselect [\code{integer(1)}]\cr
+#' @param nselect (`integer(1)`)\cr
 #'   Number of scores to request. Scores are getting calculated for all features per default.
-#' @param ... [any]\cr
-#'   Passed down to selected method. Can only be use if \code{method} contains one element.
-#' @param more.args [named list]\cr
+#' @param ... (any)\cr
+#'   Passed down to selected method. Can only be use if `method` contains one element.
+#' @param more.args (named [list])\cr
 #'   Extra args passed down to filter methods. List elements are named with the filter
-#'   \code{method} name the args should be passed down to.
-#'   A more general and flexible option than \code{...}.
+#'   `method` name the args should be passed down to.
+#'   A more general and flexible option than `...`.
 #'   Default is empty list.
-#' @return [\code{FilterValues}]. A \code{list} containing:
-#'   \item{task.desc}{[\code{\link{TaskDesc}}]\cr
+#' @return ([FilterValues]). A `list` containing:
+#'   \item{task.desc}{[[TaskDesc])\cr
 #'     Task description.}
-#'   \item{data}{[\code{data.frame}] with columns:
+#'   \item{data}{([data.frame]) with columns:
 #'     \itemize{
-#'       \item \code{name}[\code{character}]\cr
+#'       \item `name`([character])\cr
 #'         Name of feature.
-#'       \item \code{type}[\code{character}]\cr
+#'       \item `type`([character])\cr
 #'         Feature column type.
-#'       \item \code{method}[\code{numeric}]\cr 
+#'       \item `method`([numeric])\cr
 #'         One column for each method with the feature importance values.
 #'     }}
 #' @family generate_plot_data
@@ -40,17 +40,17 @@ generateFilterValuesData = function(task, method = "randomForestSRC.rfsrc", nsel
   filter = lapply(method, function(x) .FilterRegister[[x]])
   if (!(any(sapply(filter, function(x) !isScalarNA(filter$pkg)))))
     lapply(filter, function(x) requirePackages(x$pkg, why = "generateFilterValuesData", default.method = "load"))
-  check_task = sapply(filter, function(x) td$type %nin% x$supported.tasks)
-  if (any(check_task))
+  check.task = sapply(filter, function(x) td$type %nin% x$supported.tasks)
+  if (any(check.task))
     stopf("Filter(s) %s not compatible with task of type '%s'",
-          stri_paste("'", method[check_task], "'", collapse = ", "), td$type)
+          stri_paste("'", method[check.task], "'", collapse = ", "), td$type)
 
-  check_feat = lapply(filter, function(x) setdiff(names(td$n.feat[td$n.feat > 0L]), x$supported.features))
-  check_length = sapply(check_feat, length) > 0L
-  if (any(check_length)) {
+  check.feat = lapply(filter, function(x) setdiff(names(td$n.feat[td$n.feat > 0L]), x$supported.features))
+  check.length = sapply(check.feat, length) > 0L
+  if (any(check.length)) {
     stopf("Filter(s) %s not compatible with features of type %s respectively",
-          stri_paste("'", method[check_length], "'", collapse = ", "),
-          stri_paste(sapply(check_feat[check_length], function(x) stri_paste("'", x, "'", collapse = ", ")), collapse = ", and "))
+          stri_paste("'", method[check.length], "'", collapse = ", "),
+          stri_paste(sapply(check.feat[check.length], function(x) stri_paste("'", x, "'", collapse = ", ")), collapse = ", and "))
   }
   assertCount(nselect)
   assertList(more.args, names = "unique", max.len = length(method))
@@ -100,18 +100,18 @@ print.FilterValues = function(x, ...) {
 #'
 #' @description
 #' Calculates numerical filter values for features.
-#' For a list of features, use \code{\link{listFilterMethods}}.
+#' For a list of features, use [listFilterMethods].
 #'
 #' @template arg_task
-#' @param method [\code{character(1)}]\cr
+#' @param method (`character(1)`)\cr
 #'   Filter method, see above.
 #'   Default is \dQuote{randomForestSRC.rfsrc}.
-#' @param nselect [\code{integer(1)}]\cr
+#' @param nselect (`integer(1)`)\cr
 #'   Number of scores to request. Scores are getting calculated for all features per default.
-#' @param ... [any]\cr
+#' @param ... (any)\cr
 #'   Passed down to selected method.
-#' @return [\code{\link{FilterValues}}].
-#' @note \code{getFilterValues} is deprecated in favor of \code{\link{generateFilterValuesData}}.
+#' @return ([FilterValues]).
+#' @note `getFilterValues` is deprecated in favor of [generateFilterValuesData].
 #' @family filter
 #' @export
 getFilterValues = function(task, method = "randomForestSRC.rfsrc", nselect = getTaskNFeats(task), ...) {
@@ -119,7 +119,7 @@ getFilterValues = function(task, method = "randomForestSRC.rfsrc", nselect = get
   assertChoice(method, choices = ls(.FilterRegister))
   out = generateFilterValuesData(task, method, nselect, ...)
   colnames(out$data)[3] = "val"
-  out$data = out$data[, c(1,3,2)]
+  out$data = out$data[, c(1, 3, 2)]
   makeS3Obj("FilterValues",
             task.desc = out$task.desc,
             method = method,
@@ -130,19 +130,19 @@ getFilterValues = function(task, method = "randomForestSRC.rfsrc", nselect = get
 #' @family filter
 #' @family generate_plot_data
 #'
-#' @param fvalues [\code{\link{FilterValues}}]\cr
+#' @param fvalues ([FilterValues])\cr
 #'   Filter values.
-#' @param sort [\code{character(1)}]\cr
+#' @param sort (`character(1)`)\cr
 #'   Sort features like this.
 #'   \dQuote{dec} = decreasing, \dQuote{inc} = increasing, \dQuote{none} = no sorting.
 #'   Default is decreasing.
-#' @param n.show [\code{integer(1)}]\cr
+#' @param n.show (`integer(1)`)\cr
 #'   Number of features (maximal) to show.
 #'   Default is 20.
-#' @param feat.type.cols [\code{logical(1)}]\cr
+#' @param feat.type.cols (`logical(1)`)\cr
 #'   Colors for factor and numeric features.
-#'   \code{FALSE} means no colors.
-#'   Default is \code{FALSE}.
+#'   `FALSE` means no colors.
+#'   Default is `FALSE`.
 #' @template arg_facet_nrow_ncol
 #' @template ret_gg2
 #' @export
@@ -162,9 +162,11 @@ plotFilterValues = function(fvalues, sort = "dec", n.show = 20L, feat.type.cols
   n.show = min(n.show, max(sapply(methods, function(x) sum(!is.na(data[[x]])))))
   data = melt(as.data.table(data), id.vars = c("name", "type"), variable = "method")
 
-  if (sort != "none")
-    data = do.call(rbind, lapply(methods, function(x)
-      head(sortByCol(data[data$method == x, ], "value", (sort == "inc")), n.show)))
+  if (sort != "none") {
+    sort.mult = if (sort == "inc") 1 else -1
+    setorderv(data, "value", sort.mult)
+    data = data[get("method") %in% methods, head(.SD, n.show), by = "method"]
+  }
 
   data$name = factor(data$name, levels = as.character(unique(data$name)))
   if (feat.type.cols)
@@ -190,88 +192,3 @@ plotFilterValues = function(fvalues, sort = "dec", n.show = 20L, feat.type.cols
   plt = plt + theme(axis.text.x = element_text(angle = 45, hjust = 1))
   return(plt)
 }
-#' Plot filter values using ggvis.
-#'
-#' @family plot
-#' @family filter
-#'
-#' @param fvalues [\code{\link{FilterValues}}]\cr
-#'   Filter values.
-#' @param feat.type.cols [\code{logical(1)}]\cr
-#'   Colors for factor and numeric features.
-#'   \code{FALSE} means no colors.
-#'   Default is \code{FALSE}.
-#' @template ret_ggv
-#' @export
-#' @examples \dontrun{
-#' fv = generateFilterValuesData(iris.task, method = "variance")
-#' plotFilterValuesGGVIS(fv)
-#' }
-plotFilterValuesGGVIS = function(fvalues, feat.type.cols = FALSE) {
-  requirePackages("_ggvis")
-  assertClass(fvalues, classes = "FilterValues")
-  if (!(is.null(fvalues$method)))
-    stop("fvalues must be generated by generateFilterValuesData, not getFilterValues, which is deprecated.")
-
-  data = fvalues$data
-  data = setDF(melt(as.data.table(data), id.vars = c("name", "type"), variable = "method"))
-
-  create_plot = function(data, feat.type.cols) {
-    if (feat.type.cols)
-      plt = ggvis::ggvis(data, ggvis::prop("x", as.name("name")),
-                         ggvis::prop("y", as.name("value")),
-                         ggvis::prop("fill", as.name("type")))
-    else
-      plt = ggvis::ggvis(data, ggvis::prop("x", as.name("name")),
-                         ggvis::prop("y", as.name("value")))
-
-    plt = ggvis::layer_bars(plt)
-    plt = ggvis::add_axis(plt, "y", title = "")
-    plt = ggvis::add_axis(plt, "x", title = "")
-    return(plt)
-  }
-
-  gen_plot_data = function(data, sort_type, value_column, factor_column, n_show) {
-    if (sort_type != "none") {
-      data = head(sortByCol(data, "value", FALSE), n = n_show)
-      data[[factor_column]] = factor(data[[factor_column]],
-                                     levels = data[[factor_column]][order(data[[value_column]],
-                                                                          decreasing = sort_type == "decreasing")])
-    }
-    data
-  }
-
-  requirePackages("_shiny")
-  header = shiny::headerPanel(sprintf("%s (%i features)", fvalues$task.desc$id, sum(fvalues$task.desc$n.feat)))
-  method_input = shiny::selectInput("level_variable", "choose a filter method",
-                                    unique(levels(data[["method"]])))
-  sort_input = shiny::radioButtons("sort_type", "sort features", c("increasing", "decreasing", "none"))
-  n_show_input = shiny::numericInput("n_show", "number of features to show",
-                                     value = sum(fvalues$task.desc$n.feat),
-                                     min = 1,
-                                     max = sum(fvalues$task.desc$n.feat),
-                                     step = 1)
-  ui = shiny::shinyUI(
-    shiny::pageWithSidebar(
-      header,
-      shiny::sidebarPanel(method_input, sort_input, n_show_input),
-      shiny::mainPanel(shiny::uiOutput("ggvis_ui"), ggvis::ggvisOutput("ggvis"))
-    )
-  )
-  server = shiny::shinyServer(function(input, output) {
-    plt = shiny::reactive(
-      create_plot(
-        data = gen_plot_data(
-          data[which(data[["method"]] == input$level_variable), ],
-          input$sort_type,
-          "value",
-          "name",
-          input$n_show
-        ),
-        feat.type.cols
-      )
-    )
-    ggvis::bind_shiny(plt, "ggvis", "ggvis_ui")
-  })
-  shiny::shinyApp(ui, server)
-}
