@@ -3,17 +3,17 @@
 #' @description
 #' Retrieves the current hyperparameter settings of a learner.
 #'
-#' @template arg_learner
-#' @param for.fun [\code{character(1)}]\cr
-#'   Restrict the returned settings to hyperparameters corresponding to \code{when}
-#'   the are used (see \code{\link[ParamHelpers]{LearnerParam}}).
+#' @param learner ([Learner])\cr
+#'   The learner.
+#' @param for.fun (`character(1)`)\cr
+#'   Restrict the returned settings to hyperparameters corresponding to `when`
+#'   the are used (see [ParamHelpers::LearnerParam]).
 #'   Must be a subset of: \dQuote{train}, \dQuote{predict} or \dQuote{both}.
-#'   Default is \code{c("train", "predict", "both")}.
-#' @return [\code{list}]. A named list of values.
+#'   Default is `c("train", "predict", "both")`.
+#' @return ([list]). A named list of values.
 #' @family learner
 #' @export
 getHyperPars = function(learner,  for.fun = c("train", "predict", "both")) {
-  assertClass(learner, classes = "Learner")
   assertSubset(for.fun, choices = c("train", "predict", "both"))
   UseMethod("getHyperPars")
 }
