@@ -1,7 +1,7 @@
 #' @title Visualizes a learning algorithm on a 1D or 2D data set.
 #'
 #' @description
-#' Trains the model for 1 or 2 selected features, then displays it via \code{\link[ggplot2]{ggplot}}.
+#' Trains the model for 1 or 2 selected features, then displays it via [ggplot2::ggplot].
 #' Good for teaching or exploring models.
 #'
 #' For classification and clustering, only 2D plots are supported. The data points, the classification and
@@ -16,47 +16,47 @@
 #'
 #' @template arg_learner
 #' @template arg_task
-#' @param features [\code{character}]\cr
+#' @param features ([character])\cr
 #'   Selected features for model.
 #'   By default the first 2 features are used.
 #' @template arg_measures
-#' @param cv [\code{integer(1)}]\cr
+#' @param cv (`integer(1)`)\cr
 #'   Do cross-validation and display in plot title?
 #'   Number of folds. 0 means no CV.
 #'   Default is 10.
-#' @param ... [any]\cr
-#'   Parameters for \code{learner}.
-#' @param gridsize [\code{integer(1)}]\cr
+#' @param ... (any)\cr
+#'   Parameters for `learner`.
+#' @param gridsize (`integer(1)`)\cr
 #'   Grid resolution per axis for background predictions.
 #'   Default is 500 for 1D and 100 for 2D.
-#' @param pointsize [\code{numeric(1)}]\cr
-#'   Pointsize for ggplot2 \code{\link[ggplot2]{geom_point}} for data points.
+#' @param pointsize (`numeric(1)`)\cr
+#'   Pointsize for ggplot2 [ggplot2::geom_point] for data points.
 #'   Default is 2.
-#' @param prob.alpha [\code{logical(1)}]\cr
+#' @param prob.alpha (`logical(1)`)\cr
 #'   For classification: Set alpha value of background to probability for
 #'   predicted class? Allows visualization of \dQuote{confidence} for prediction.
 #'   If not, only a constant color is displayed in the background for the predicted label.
-#'   Default is \code{TRUE}.
-#' @param se.band [\code{logical(1)}]\cr
+#'   Default is `TRUE`.
+#' @param se.band (`logical(1)`)\cr
 #'   For regression in 1D: Show band for standard error estimation?
-#'   Default is \code{TRUE}.
-#' @param err.mark [\code{character(1)}]:
+#'   Default is `TRUE`.
+#' @param err.mark (`character(1)`):
 #'   For classification: Either mark error of the model on the training data (\dQuote{train}) or
 #'   during cross-validation (\dQuote{cv}) or not at all with \dQuote{none}.
 #'   Default is \dQuote{train}.
-#' @param bg.cols [\code{character(3)}]\cr
+#' @param bg.cols (`character(3)`)\cr
 #'   Background colors for classification and regression.
 #'   Sorted from low, medium to high.
-#'   Default is \code{TRUE}.
-#' @param err.col [\code{character(1)}]\cr
+#'   Default is `TRUE`.
+#' @param err.col (`character(1)`)\cr
 #'   For classification: Color of misclassified data points.
 #'   Default is \dQuote{white}
-#' @param err.size [\code{integer(1)}]\cr
+#' @param err.size (`integer(1)`)\cr
 #'   For classification: Size of misclassified data points.
-#'   Default is \code{pointsize}.
-#' @param greyscale [\code{logical(1)}]\cr
+#'   Default is `pointsize`.
+#' @param greyscale (`logical(1)`)\cr
 #'   Should the plot be greyscale completely?
-#'   Default is \code{FALSE}.
+#'   Default is `FALSE`.
 #' @template arg_prettynames
 #' @return The ggplot2 object.
 #' @export
@@ -162,11 +162,11 @@ plotLearnerPrediction = function(learner, task, features = NULL, measures, cv =
 
   if (td$type == "classif") {
     data$.err = if (err.mark == "train")
-      (y != yhat)
+      y != yhat
     else if (err.mark == "cv")
       y != pred.cv$data[order(pred.cv$data$id), "response"]
     else
-      NULL
+      TRUE
     if (taskdim == 2L) {
       p = ggplot(grid, aes_string(x = x1n, y = x2n))
       if (hasLearnerProperties(learner, "prob") && prob.alpha) {
@@ -174,7 +174,7 @@ plotLearnerPrediction = function(learner, task, features = NULL, measures, cv =
         prob = apply(getPredictionProbabilities(pred.grid, cl = td$class.levels), 1, max)
         grid$.prob.pred.class = prob
         p = p + geom_tile(data = grid, mapping = aes_string(fill = target, alpha = ".prob.pred.class"),
-          show.legend = TRUE)
+          show.legend = TRUE) + scale_fill_discrete(drop = FALSE)
         p = p + scale_alpha(limits = range(grid$.prob.pred.class))
       } else {
         p = p + geom_tile(mapping = aes_string(fill = target))
