@@ -46,9 +46,9 @@ test_that("clustering resample",  {
 })
 
 test_that("clustering benchmark", {
-  task.names = c("noclass")
+  task.names = "noclass"
   tasks = list(noclass.task)
-  learner.names = c("cluster.SimpleKMeans")
+  learner.names = "cluster.SimpleKMeans"
   learners = lapply(learner.names, makeLearner)
   rin = makeResampleDesc("CV", iters = 2L)
 
@@ -57,7 +57,7 @@ test_that("clustering benchmark", {
 })
 
 test_that("clustering downsample", {
-  down.tsk = downsample(noclass.task, perc = 1/3)
+  down.tsk = downsample(noclass.task, perc = 1 / 3)
   expect_equal(getTaskSize(down.tsk), 50L)
 })
 
