@@ -14,14 +14,14 @@ test_that("BenchmarkSummary", {
   # pretty.names works
   plotBMRSummary(res)
   dir = tempdir()
-  path = paste0(dir, "/test.svg")
+  path = file.path(dir, "test.svg")
   ggsave(path)
   doc = XML::xmlParse(path)
   testDocForStrings(doc, getBMRLearnerShortNames(res))
 
   plotBMRSummary(res, pretty.names = FALSE)
   dir = tempdir()
-  path = paste0(dir, "/test.svg")
+  path = file.path(dir, "test.svg")
   ggsave(path)
   doc = XML::xmlParse(path)
   testDocForStrings(doc, getBMRLearnerIds(res))
