@@ -9,7 +9,7 @@ test_that("classif_LiblineaRL2SVC", {
     list(type = 1L, cost = 5L),
     list(type = 2L, cost = 5L)
   )
-  
+
   parset.list2 = list(
     list(),
     list(type = 1L),
@@ -20,7 +20,7 @@ test_that("classif_LiblineaRL2SVC", {
   old.predicts.list = list()
   old.probs.list = list()
 
-  for (i in 1L:length(parset.list1)) {
+  for (i in seq_along(parset.list1)) {
     parset = parset.list1[[i]]
     pars = list(data = binaryclass.train[, -binaryclass.class.col],
       target = binaryclass.train[, binaryclass.target])
@@ -31,7 +31,7 @@ test_that("classif_LiblineaRL2SVC", {
     p = predict(m, newx = binaryclass.test[, -binaryclass.class.col])
     old.predicts.list[[i]] = as.factor(p$predictions)
   }
-  
+
   testSimpleParsets("classif.LiblineaRL2SVC", binaryclass.df, binaryclass.target,
     binaryclass.train.inds, old.predicts.list, parset.list2)
 
