@@ -1,7 +1,8 @@
 context("classif_ctree")
 
 test_that("classif_ctree", {
-  library(party)
+  requirePackagesOrSkip("party", default.method = "load")
+
   parset.list = list(
     list(),
     list(minsplit = 10, mincriterion = 0.005),
@@ -13,35 +14,30 @@ test_that("classif_ctree", {
   old.predicts.list = list()
   old.probs.list = list()
 
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
-    ctrl = do.call(ctree_control, parset)
+    ctrl = do.call(party::ctree_control, parset)
     set.seed(getOption("mlr.debug.seed"))
-    m = ctree(formula = multiclass.formula, data = multiclass.train, control = ctrl)
+    m = party::ctree(formula = multiclass.formula, data = multiclass.train, control = ctrl)
     p  = predict(m, newdata = multiclass.test, type = "response")
-    p2 = Reduce(rbind, treeresponse(m, newdata = multiclass.test, type = "prob"))
+    p2 = Reduce(rbind, party::treeresponse(m, newdata = multiclass.test, type = "prob"))
     rownames(p2) = NULL
-    colnames(p2) = levels(multiclass.df[,multiclass.target])
+    colnames(p2) = levels(multiclass.df[, multiclass.target])
     old.predicts.list[[i]] = p
     old.probs.list[[i]] = p2
   }
 
-  testSimpleParsets("classif.ctree", multiclass.df, multiclass.target, multiclass.train.inds, 
+  testSimpleParsets("classif.ctree", multiclass.df, multiclass.target, multiclass.train.inds,
     old.predicts.list, parset.list)
-  testProbParsets  ("classif.ctree", multiclass.df, multiclass.target, multiclass.train.inds, 
+  testProbParsets("classif.ctree", multiclass.df, multiclass.target, multiclass.train.inds,
     old.probs.list, parset.list)
 
   df = iris
-  df[,1] = 1:150
-  df1 = df[seq(1,150,2), ]
-  df2 = df[seq(2,150,2), ]
+  df[, 1] = 1:150
+  df1 = df[seq(1, 150, 2), ]
+  df2 = df[seq(2, 150, 2), ]
   ct = makeClassifTask(target = "Species", data = df1)
   m = train(makeLearner("classif.ctree"), ct)
   predict(m, newdata = df2)
 
 })
-
-
-
-
-
