@@ -5,12 +5,12 @@ test_that("cluster_FarthestFirst", {
 
   parset.list = list(
     list(),
-    list(N=3)
+    list(N = 3)
   )
 
   old.predicts.list = list()
 
-  for (i in 1:length(parset.list)) {
+  for (i in seq_along(parset.list)) {
     parset = parset.list[[i]]
     ctrl = do.call(RWeka::Weka_control, parset)
     set.seed(getOption("mlr.debug.seed"))
